@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.145-8-g9ce3dfe
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.146-4-g4bb3c9e
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 
-our $VERSION = '0.146';
+our $VERSION = '0.147';
 
 use Moose;
 with
@@ -79,7 +79,10 @@ has copy_file_from_release => (
 
 around copy_files_from_release => sub {
     my $orig = shift; my $self = shift;
-    sort(uniq($self->$orig(@_), qw(LICENCE LICENSE CONTRIBUTING ppport.h INSTALL)));
+    sort(uniq($self->$orig(@_),
+            qw(LICENCE LICENSE CONTRIBUTING ppport.h INSTALL),
+            $self->cpanfile ? 'cpanfile' : (),
+        ));
 };
 
 sub commit_files_after_release
@@ -104,7 +107,8 @@ has licence => (
         $self->payload->{licence}
             // $self->payload->{license}
             # licenSe is US-only; known non-American authors will be treated appropriately.
-            // ((any { $authority eq "cpan:$_" } qw(ETHER ABERGMAN AVAR BINGOS BOBTFISH CHANSEN CHOLET FLORA GETTY ILMARI JAWNSY JQUELIN LEONT LLAP MSTROUT NUFFIN PERIGRIN PHAYLON))
+            // ((any { $authority eq "cpan:$_" }
+                    qw(ETHER ABERGMAN AVAR BINGOS BOBTFISH CHANSEN CHOLET DOHERTY FLORA GAAS GETTY GSAR ILMARI JAWNSY JQUELIN LBROCARD LEONT LLAP MANWAR MSTROUT NEILB NUFFIN OALDERS PERIGRIN PHAYLON SALVA))
                 ? 'LICENCE' : 'LICENSE');
     },
 );
@@ -146,6 +150,13 @@ has plugin_prereq_relationship => (
     default => sub { $_[0]->payload->{plugin_prereq_relationship} // 'requires' },
 );
 
+has cpanfile => (
+    is => 'ro', isa => 'Bool',
+    init_arg => undef,
+    lazy => 1,
+    default => sub { $_[0]->payload->{cpanfile} // 0 },
+);
+
 # configs are applied when plugins match ->isa($key) or ->does($key)
 my %extra_args = (
     'Dist::Zilla::Plugin::MakeMaker' => { 'eumm_version' => '0' },
@@ -307,6 +318,9 @@ sub configure
         [ 'Git::GatherDir'      => { ':version' => '2.016', @never_gather ? ( exclude_filename => \@never_gather) : () } ],
 
         qw(MetaYAML MetaJSON Readme Manifest),
+
+        $self->cpanfile ? [ 'CPANFile' ] : (),
+
         [ 'License'             => { ':version' => '5.038', filename => $self->licence } ],
         [ 'GenerateFile::FromShareDir' => 'generate CONTRIBUTING' => { -dist => 'Dist-Zilla-PluginBundle-Author-ETHER', -filename => 'CONTRIBUTING', has_xs => $has_xs } ],
         [ 'InstallGuide'        => { ':version' => '1.200005' } ],
@@ -616,7 +630,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.146
+version 0.147
 
 =head1 SYNOPSIS
 
@@ -676,6 +690,8 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     :version = 5.038
     filename = LICENCE  ; for distributions where I have authority
 
+    [CPANFile] ; iff cpanfile = 1
+
     [GenerateFile::FromShareDir / generate CONTRIBUTING]
     -dist = Dist-Zilla-PluginBundle-Author-ETHER
     -filename = CONTRIBUTING
@@ -923,6 +939,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     filename = LICENCE
     filename = LICENSE
     filename = ppport.h
+    filename = cpanfile     ; iff cpanfile = 1
 
     [ReadmeAnyFromPod]
     :version = 0.142180
@@ -952,6 +969,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     allow_dirty = LICENSE
     allow_dirty = README.md
     allow_dirty = README.pod
+    allow_dirty = cpanfile  ; iff cpanfile = 1
     allow_dirty = ppport.h
     commit_msg = %N-%v%t%n%n%c
 
@@ -1140,7 +1158,8 @@ Available in this form since version 0.076.
 A file, to be present in the build, which is copied back to the source
 repository at release time and committed to git. Can be used more than
 once. Defaults to:
-F<LICENCE>, F<LICENSE>, F<CONTRIBUTING>, F<Changes>, F<ppport.h>, F<INSTALL>;
+F<LICENCE>, F<LICENSE>, F<CONTRIBUTING>, F<Changes>, F<ppport.h>, F<INSTALL>,
+as well as F<cpanfile> if C<cpanfile = 1> is specified in the options;
 defaults are appended to, rather than overwritten.
 
 =head2 surgical_podweaver
@@ -1190,8 +1209,6 @@ A boolean option that, when set, removes L<[UploadToCPAN]|Dist::Zilla::Plugin::U
 and replaces it with L<[FakeRelease]|Dist::Zilla::Plugin::FakeRelease>.
 Defaults to false; can also be set with the environment variable C<FAKE_RELEASE>.
 
-=for stopwords customizations
-
 =head2 plugin_prereq_phase, plugin_prereq_relationship
 
 If these are set, then plugins used by the bundle (with minimum version requirements) are injected into the
@@ -1203,6 +1220,18 @@ Disable with:
 
 Available since version 0.133.
 
+=for stopwords cpanfile
+
+=head2 cpanfile
+
+Available since version 0.147.
+
+A boolean option that, when set, adds a F<cpanfile> to the built distribution and also commits it to the local
+repository after release. Beware that if the distribution has C<< dynamic_config => 1 >> in metadata, this will
+I<not> be a complete list of prerequisites.
+
+=for stopwords customizations
+
 =head2 other customizations
 
 This bundle makes use of L<Dist::Zilla::Role::PluginBundle::PluginRemover> and
